==> scala-relay-compiler-0.8.2.tgz: package/realex/multipleroots/out/UserView.scala <==
/**
 * scala-relay-compiler: 
 * @relayHash 0fb79fb770ea22b7358fcc9f92ea6449
 * GENERATED, DON'T MANUALLY EDIT.
 */
package relay.generated
/*

objName:      batch
docType:      ConcreteBatch
*/

import _root_.scala.scalajs.js
import _root_.scala.scalajs.js.|

trait UserViewInput extends js.Object {
  val id : String
}
trait UserView extends js.Object {
  /** New fields added, conflicts detected. */
  val node : UserView.Node
  /** New fields added, conflicts detected. */
  val viewer : UserView.Viewer
}


/*
query UserView(
  $id: ID!
) {
  viewer {
    id
    ...SpecificUserView_viewer
  }
  node(id: $id) {
    __typename
    id
    ... on FullUser {
      ...SpecificUserView_fullUser
    }
  }
}

fragment SpecificUserView_viewer on Viewer {
  id
  user {
    id
    user {
      firstName
      lastName
      id
    }
  }
  ...AdminCore_viewer
}

fragment SpecificUserView_fullUser on FullUser {
  rawId
  id
  policies {
    edges {
      node {
        quoteId
        id
      }
    }
  }
}

fragment AdminCore_viewer on Viewer {
  id
  user {
    user {
      id
      firstName
      lastName
    }
    roles
    permissions
    id
  }
}
*/

object UserView extends _root_.relay.graphql.QueryTaggedNode[UserViewInput, UserView] {

  ////////////////////////////////////
  ////// Supporting classes begin here
  ////////////////////////////////////
  trait Viewer extends js.Object {
    val id : String
  }
  trait NodeFullUser extends js.Object {

  }
  trait Node extends js.Object {
    val id : String
    val __typename : String
  }

  ///////////////////////////
  ////// Implicits begin here
  ///////////////////////////
  implicit class Node_Ops(f: Node) {
    def asFullUser: Option[NodeFullUser] = {
      if (f.__typename == "FullUser") Some(f.asInstanceOf[NodeFullUser])
      else None
    }
  }
  implicit def NodeFullUser2SpecificUserView_fullUser(f: NodeFullUser): SpecificUserView_fullUser = f.asInstanceOf[SpecificUserView_fullUser]
  implicit def Viewer2SpecificUserView_viewer(f: Viewer): SpecificUserView_viewer = f.asInstanceOf[SpecificUserView_viewer]

  val query: _root_.relay.graphql.ConcreteBatch = _root_.scala.scalajs.js.JSON.parse("""{
  "fragment": {
    "argumentDefinitions": [
      {
        "kind": "LocalArgument",
        "name": "id",
        "type": "ID!",
        "defaultValue": null
      }
    ],
    "kind": "Fragment",
    "metadata": null,
    "name": "UserView",
    "selections": [
      {
        "kind": "LinkedField",
        "alias": null,
        "args": null,
        "concreteType": "Viewer",
        "name": "viewer",
        "plural": false,
        "selections": [
          {
            "kind": "ScalarField",
            "alias": null,
            "args": null,
            "name": "id",
            "storageKey": null
          },
          {
            "kind": "FragmentSpread",
            "name": "SpecificUserView_viewer",
            "args": null
          }
        ],
        "storageKey": null
      },
      {
        "kind": "LinkedField",
        "alias": null,
        "args": [
          {
            "kind": "Variable",
            "name": "id",
            "variableName": "id",
            "type": "ID!"
          }
        ],
        "concreteType": null,
        "name": "node",
        "plural": false,
        "selections": [
          {
            "kind": "ScalarField",
            "alias": null,
            "args": null,
            "name": "id",
            "storageKey": null
          },
          {
            "kind": "InlineFragment",
            "type": "FullUser",
            "selections": [
              {
                "kind": "FragmentSpread",
                "name": "SpecificUserView_fullUser",
                "args": null
              }
            ]
          }
        ],
        "storageKey": null
      }
    ],
    "type": "Root"
  },
  "id": null,
  "kind": "Batch",
  "metadata": {},
  "name": "UserView",
  "query": {
    "argumentDefinitions": [
      {
        "kind": "LocalArgument",
        "name": "id",
        "type": "ID!",
        "defaultValue": null
      }
    ],
    "kind": "Root",
    "name": "UserView",
    "operation": "query",
    "selections": [
      {
        "kind": "LinkedField",
        "alias": null,
        "args": null,
        "concreteType": "Viewer",
        "name": "viewer",
        "plural": false,
        "selections": [
          {
            "kind": "ScalarField",
            "alias": null,
            "args": null,
            "name": "id",
            "storageKey": null
          },
          {
            "kind": "InlineFragment",
            "type": "Viewer",
            "selections": [
              {
                "kind": "LinkedField",
                "alias": null,
                "args": null,
                "concreteType": "FullUser",
                "name": "user",
                "plural": false,
                "selections": [
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "id",
                    "storageKey": null
                  },
                  {
                    "kind": "LinkedField",
                    "alias": null,
                    "args": null,
                    "concreteType": "User",
                    "name": "user",
                    "plural": false,
                    "selections": [
                      {
                        "kind": "ScalarField",
                        "alias": null,
                        "args": null,
                        "name": "firstName",
                        "storageKey": null
                      },
                      {
                        "kind": "ScalarField",
                        "alias": null,
                        "args": null,
                        "name": "lastName",
                        "storageKey": null
                      },
                      {
                        "kind": "ScalarField",
                        "alias": null,
                        "args": null,
                        "name": "id",
                        "storageKey": null
                      }
                    ],
                    "storageKey": null
                  },
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "roles",
                    "storageKey": null
                  },
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "permissions",
                    "storageKey": null
                  }
                ],
                "storageKey": null
              }
            ]
          }
        ],
        "storageKey": null
      },
      {
        "kind": "LinkedField",
        "alias": null,
        "args": [
          {
            "kind": "Variable",
            "name": "id",
            "variableName": "id",
            "type": "ID!"
          }
        ],
        "concreteType": null,
        "name": "node",
        "plural": false,
        "selections": [
          {
            "kind": "ScalarField",
            "alias": null,
            "args": null,
            "name": "__typename",
            "storageKey": null
          },
          {
            "kind": "ScalarField",
            "alias": null,
            "args": null,
            "name": "id",
            "storageKey": null
          },
          {
            "kind": "InlineFragment",
            "type": "FullUser",
            "selections": [
              {
                "kind": "ScalarField",
                "alias": null,
                "args": null,
                "name": "rawId",
                "storageKey": null
              },
              {
                "kind": "LinkedField",
                "alias": null,
                "args": null,
                "concreteType": "PolicyMaterializedConnection",
                "name": "policies",
                "plural": false,
                "selections": [
                  {
                    "kind": "LinkedField",
                    "alias": null,
                    "args": null,
                    "concreteType": "PolicyMaterializedEdge",
                    "name": "edges",
                    "plural": true,
                    "selections": [
                      {
                        "kind": "LinkedField",
                        "alias": null,
                        "args": null,
                        "concreteType": "PolicyMaterialized",
                        "name": "node",
                        "plural": false,
                        "selections": [
                          {
                            "kind": "ScalarField",
                            "alias": null,
                            "args": null,
                            "name": "quoteId",
                            "storageKey": null
                          },
                          {
                            "kind": "ScalarField",
                            "alias": null,
                            "args": null,
                            "name": "id",
                            "storageKey": null
                          }
                        ],
                        "storageKey": null
                      }
                    ],
                    "storageKey": null
                  }
                ],
                "storageKey": null
              }
            ]
          }
        ],
        "storageKey": null
      }
    ]
  },
  "text": "query UserView(\n  $id: ID!\n) {\n  viewer {\n    id\n    ...SpecificUserView_viewer\n  }\n  node(id: $id) {\n    __typename\n    id\n    ... on FullUser {\n      ...SpecificUserView_fullUser\n    }\n  }\n}\n\nfragment SpecificUserView_viewer on Viewer {\n  id\n  user {\n    id\n    user {\n      firstName\n      lastName\n      id\n    }\n  }\n  ...AdminCore_viewer\n}\n\nfragment SpecificUserView_fullUser on FullUser {\n  rawId\n  id\n  policies {\n    edges {\n      node {\n        quoteId\n        id\n      }\n    }\n  }\n}\n\nfragment AdminCore_viewer on Viewer {\n  id\n  user {\n    user {\n      id\n      firstName\n      lastName\n    }\n    roles\n    permissions\n    id\n  }\n}\n"
}""").asInstanceOf[_root_.relay.graphql.ConcreteBatch]
  val devText: String = """"""
}

==> scala-relay-compiler-0.9.0.tgz: package/realex/multipleroots/out/UserView.scala <==
/**
 * scala-relay-compiler: 
 * GENERATED, DON'T MANUALLY EDIT.
 * objName:      fragment
 * docType:      ConcreteFragment
 */
package relay.generated

import _root_.scala.scalajs.js
import _root_.scala.scalajs.js.|

trait UserViewInput extends js.Object {
  val id : String
}
trait UserView extends js.Object {
  /** New fields added, conflicts detected. */
  val node : UserView.Node
  /** New fields added, conflicts detected. */
  val viewer : UserView.Viewer
}


object UserView extends _root_.relay.graphql.QueryTaggedNode[UserViewInput, UserView] {

  ////////////////////////////////////
  ////// Supporting classes begin here
  ////////////////////////////////////
  trait Viewer extends js.Object {
    val id : String
  }
  trait NodeFullUser extends js.Object with Foo12 {
    val id : String
  }
  trait Node extends js.Object with Foo {
    val id : String
    val __typename : String
  }

  ///////////////////////////
  ////// Implicits begin here
  ///////////////////////////
  implicit class Node_Ops(f: Node) {
    def asFullUser: Option[NodeFullUser] = {
      if (f.__typename == "FullUser") Some(f.asInstanceOf[NodeFullUser])
      else None
    }
  }
  implicit def NodeFullUser2SpecificUserView_fullUser(f: NodeFullUser): SpecificUserView_fullUser = f.asInstanceOf[SpecificUserView_fullUser]
  implicit def Viewer2SpecificUserView_viewer(f: Viewer): SpecificUserView_viewer = f.asInstanceOf[SpecificUserView_viewer]

  val query: _root_.relay.graphql.ConcreteFragment = _root_.scala.scalajs.js.eval("""((function(){
var v0 = [
  {
    "kind": "LocalArgument",
    "name": "id",
    "type": "ID!",
    "defaultValue": null
  }
],
v1 = {
  "kind": "ScalarField",
  "alias": null,
  "name": "id",
  "args": null,
  "storageKey": null
},
v2 = [
  {
    "kind": "Variable",
    "name": "id",
    "variableName": "id",
    "type": "ID!"
  }
];
return {
  "kind": "Request",
  "operationKind": "query",
  "name": "UserView",
  "id": null,
  "text": "query UserView(\n  $id: ID!\n) {\n  viewer {\n    id\n    ...SpecificUserView_viewer\n  }\n  node(id: $id) {\n    __typename\n    id\n    ... on FullUser {\n      id\n      ...SpecificUserView_fullUser\n    }\n  }\n}\n\nfragment SpecificUserView_viewer on Viewer {\n  id\n  user {\n    id\n    user {\n      firstName\n      lastName\n      id\n    }\n  }\n  ...AdminCore_viewer\n}\n\nfragment SpecificUserView_fullUser on FullUser {\n  rawId\n  id\n  policies {\n    edges {\n      node {\n        quoteId\n        id\n      }\n    }\n  }\n}\n\nfragment AdminCore_viewer on Viewer {\n  id\n  user {\n    user {\n      id\n      firstName\n      lastName\n    }\n    roles\n    permissions\n    id\n  }\n}\n",
  "metadata": {},
  "fragment": {
    "kind": "Fragment",
    "name": "UserView",
    "type": "Root",
    "metadata": null,
    "argumentDefinitions": v0,
    "selections": [
      {
        "kind": "LinkedField",
        "alias": null,
        "name": "viewer",
        "storageKey": null,
        "args": null,
        "concreteType": "Viewer",
        "plural": false,
        "selections": [
          v1,
          {
            "kind": "FragmentSpread",
            "name": "SpecificUserView_viewer",
            "args": null
          }
        ]
      },
      {
        "kind": "LinkedField",
        "alias": null,
        "name": "node",
        "storageKey": null,
        "args": v2,
        "concreteType": null,
        "plural": false,
        "selections": [
          v1,
          {
            "kind": "InlineFragment",
            "type": "FullUser",
            "selections": [
              {
                "kind": "FragmentSpread",
                "name": "SpecificUserView_fullUser",
                "args": null
              }
            ]
          }
        ]
      }
    ]
  },
  "operation": {
    "kind": "Operation",
    "name": "UserView",
    "argumentDefinitions": v0,
    "selections": [
      {
        "kind": "LinkedField",
        "alias": null,
        "name": "viewer",
        "storageKey": null,
        "args": null,
        "concreteType": "Viewer",
        "plural": false,
        "selections": [
          v1,
          {
            "kind": "LinkedField",
            "alias": null,
            "name": "user",
            "storageKey": null,
            "args": null,
            "concreteType": "FullUser",
            "plural": false,
            "selections": [
              v1,
              {
                "kind": "LinkedField",
                "alias": null,
                "name": "user",
                "storageKey": null,
                "args": null,
                "concreteType": "User",
                "plural": false,
                "selections": [
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "name": "firstName",
                    "args": null,
                    "storageKey": null
                  },
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "name": "lastName",
                    "args": null,
                    "storageKey": null
                  },
                  v1
                ]
              },
              {
                "kind": "ScalarField",
                "alias": null,
                "name": "roles",
                "args": null,
                "storageKey": null
              },
              {
                "kind": "ScalarField",
                "alias": null,
                "name": "permissions",
                "args": null,
                "storageKey": null
              }
            ]
          }
        ]
      },
      {
        "kind": "LinkedField",
        "alias": null,
        "name": "node",
        "storageKey": null,
        "args": v2,
        "concreteType": null,
        "plural": false,
        "selections": [
          {
            "kind": "ScalarField",
            "alias": null,
            "name": "__typename",
            "args": null,
            "storageKey": null
          },
          v1,
          {
            "kind": "InlineFragment",
            "type": "FullUser",
            "selections": [
              {
                "kind": "ScalarField",
                "alias": null,
                "name": "rawId",
                "args": null,
                "storageKey": null
              },
              {
                "kind": "LinkedField",
                "alias": null,
                "name": "policies",
                "storageKey": null,
                "args": null,
                "concreteType": "PolicyMaterializedConnection",
                "plural": false,
                "selections": [
                  {
                    "kind": "LinkedField",
                    "alias": null,
                    "name": "edges",
                    "storageKey": null,
                    "args": null,
                    "concreteType": "PolicyMaterializedEdge",
                    "plural": true,
                    "selections": [
                      {
                        "kind": "LinkedField",
                        "alias": null,
                        "name": "node",
                        "storageKey": null,
                        "args": null,
                        "concreteType": "PolicyMaterialized",
                        "plural": false,
                        "selections": [
                          {
                            "kind": "ScalarField",
                            "alias": null,
                            "name": "quoteId",
                            "args": null,
                            "storageKey": null
                          },
                          v1
                        ]
                      }
                    ]
                  }
                ]
              }
            ]
          }
        ]
      }
    ]
  }
};
})())""").asInstanceOf[_root_.relay.graphql.ConcreteFragment]
  val devText: String = """"""
}
